import { Component, ViewChild } from '@angular/core';
import {
  ScheduleComponent, DayService, WeekService, WorkWeekService, MonthService, AgendaService, ResizeService, PopupOpenEventArgs,
  DragAndDropService, EventSettingsModel, EJ2Instance, addDays
} from '@syncfusion/ej2-angular-schedule';
import { scheduleData } from './data';
import { FormValidator } from '@syncfusion/ej2-inputs';
import { DropDownList } from '@syncfusion/ej2-dropdowns';
import { DateTimePicker } from '@syncfusion/ej2-calendars';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css'],
  providers: [DayService, WeekService, WorkWeekService, MonthService, AgendaService, ResizeService, DragAndDropService]
})
export class AppComponent {
  title = 'schedule-ang8';
  @ViewChild('scheduleObj', null)
  public scheduleObj: ScheduleComponent;
  // To disable the past days of the Scheduler
  public minDate: Date = new Date(new Date().setHours(0, 0, 0, 0));
  public selectedDate: Date = new Date(new Date().setHours(0, 0, 0, 0));
  public views: Array<string> = ['Day', 'Week', 'WorkWeek', 'Month'];
  public eventSettings: EventSettingsModel = {
    dataSource: scheduleData
  };

  onPopupOpen(args: PopupOpenEventArgs): void {
    if (args.type === 'QuickInfo') {
      // It will be triggered for the cellClick and eventClick
      const dialogObj = (args.element as any).ej2_instances[0];
      // To hide the Scheduler quick window
      dialogObj.hide();
      const currentAction = args.target.classList.contains('e-work-cells') ? 'Add' : 'Save';
      // To open the editor window by single click
      this.scheduleObj.openEditor(args.data, currentAction);
    }
    if (args.type === 'Editor') {
      const formElement: HTMLElement = args.element.querySelector('.e-schedule-form');
      const validator: FormValidator = ((formElement as EJ2Instance).ej2_instances[0] as FormValidator);
      validator.dataBind();
      // To open editor window with fixed value
      const subjectElement: HTMLInputElement = args.element.querySelector('#Subject') as HTMLInputElement;
      subjectElement.value = (args.data as any).Subject || 'Enter some text';

      const emailElement: HTMLInputElement = args.element.querySelector('#Email') as HTMLInputElement;
      emailElement.value = (args.data as any).Email || '';
      // To email address validation
      validator.addRules('Email', { email: [true] });
      const statusElement: HTMLInputElement = args.element.querySelector('#EventType') as HTMLInputElement;
      if (!statusElement.classList.contains('e-dropdownlist')) {
        const dropDownListObject: DropDownList = new DropDownList({
          placeholder: 'Choose status', value: statusElement.value,
          dataSource: ['New', 'Requested', 'Confirmed']
        });
        dropDownListObject.appendTo(statusElement);
        statusElement.setAttribute('name', 'EventType');
      }
      const startElement: HTMLInputElement = args.element.querySelector('#StartTime') as HTMLInputElement;
      if (!startElement.classList.contains('e-datetimepicker')) {
        new DateTimePicker({ value: new Date(startElement.value) || new Date() }, startElement);
      }
      const endElement: HTMLInputElement = args.element.querySelector('#EndTime') as HTMLInputElement;
      if (!endElement.classList.contains('e-datetimepicker')) {
        new DateTimePicker({ value: new Date(endElement.value) || new Date() }, endElement);
      }
      const reasonElement: HTMLInputElement = args.element.querySelector('#Description') as HTMLInputElement;
      reasonElement.value = 'This is not an editable field';
      // To disable the fied
      reasonElement.setAttribute('disabled', 'true');
    }
  }
}
